<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrn="http://xmlreleasenotes.free.fr">
	<!--
	This file belongs to XMLReleaseNotes V0.12.0.
	-->
	<!--
	This is the common XSLT that contains all the parameters and helper named templates.
	-->
	<xsl:import href="XMLReleaseNotesCommon.xsl"/>
	<xsl:output method="html" indent="yes" encoding="ISO-8859-1" omit-xml-declaration="yes"/>
	<!--
	A computed variable that tells how many columns we have.
	-->
	<xsl:variable name="_columnNumber">
		<xsl:choose>
			<xsl:when test="$delivery">3</xsl:when>
			<xsl:otherwise>2</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:template match="xrn:ReleaseNotes">
		<xsl:call-template name="_checkVersion"/>
		<xsl:choose>
			<xsl:when test="$standAloneHTML = 'true'">
				<html>
					<xsl:call-template name="_printHead">
						<xsl:with-param name="title">Release Notes of <xsl:value-of select="@ID"/>
						</xsl:with-param>
					</xsl:call-template>
					<body>
						<xsl:call-template name="_printSingle"/>
					</body>
				</html>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="_printSingle"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Prints the body content of the release notes, when a single page is being asked for.
	-->
	<xsl:template name="_printSingle">
		<span class="releaseNotes">
			<table class="releases" cellspacing="0" cellpadding="10" width="100%">
				<thead>
					<tr>
						<td colspan="{$_columnNumber}">
							<xsl:choose>
								<xsl:when test="$abstract">
									<p>
										<xsl:value-of select="$abstract" disable-output-escaping="yes"/>
									</p>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>The following table shows the history of </xsl:text>
									<b>
										<xsl:value-of select="@ID"/>
									</b>
									<xsl:text> release notes.</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</thead>
				<tbody>
					<xsl:apply-templates select="Releases"/>
				</tbody>
				<xsl:if test="$banner">
					<tfoot>
						<tr>
							<td colspan="{$_columnNumber}" class="copyrightXRNInternal">
								<xsl:call-template name="_printBottomBanner"/>
							</td>
						</tr>
					</tfoot>
				</xsl:if>
			</table>
			<br/>
		</span>
	</xsl:template>
	<!--
	Prints the HTML 'head' tag for every generated HTML page.
	Take a look at the parameters.
	-->
	<xsl:template name="_printHead">
		<xsl:param name="title"/>
		<head>
			<title>
				<xsl:value-of select="$title"/>
			</title>
			<xsl:call-template name="_printMetaAndLink"/>
		</head>
	</xsl:template>
	<!--
	Prints the HTML 'meta' and 'link' part of the 'head' tag for every generated HTML page.
	-->
	<xsl:template name="_printMetaAndLink">
		<xsl:call-template name="_printMeta"/>
		<xsl:if test="$CSS != ''">
			<link rel="StyleSheet" type="text/css" media="all">
				<xsl:attribute name="href"><xsl:value-of select="$CSS"/></xsl:attribute>
			</link>
		</xsl:if>
		<xsl:if test="$CSSContent != ''">
			<style type="text/css" media="all">
				<xsl:copy-of select="$CSSContent"/>
			</style>
		</xsl:if>
	</xsl:template>
	<!--
	Prints only the HTML 'meta' part of the 'head' tag for every generated HTML page.
	-->
	<xsl:template name="_printMeta">
		<meta name="Author" content="XMLReleaseNotes"/>
	</xsl:template>
	<xsl:template match="xrn:ReleaseNotes/Releases">
		<xsl:for-each select="Release">
			<tr>
				<xsl:attribute name="class"><xsl:choose><xsl:when test="(position() mod 2) = 0">releaseEven</xsl:when><xsl:otherwise>releaseOdd</xsl:otherwise></xsl:choose></xsl:attribute>
				<td>
					<xsl:call-template name="_printRelease"/>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>
	<!--
	Prints the content of a given release, i.e. its version header, its content, and lastly its deliveries.
	The current node must be a 'Release' XML element.
	-->
	<xsl:template name="_printRelease">
		<xsl:call-template name="_printReleaseVersion"/>
		<xsl:call-template name="_printReleaseContent"/>
		<xsl:if test="$delivery = 'true'">
			<xsl:call-template name="_printReleaseDelivery"/>
		</xsl:if>
	</xsl:template>
	<!--
	Warning, the '_printComposition', '_printRequirements' and '_printDependencies' are the same templates, as far as the logic and layout are concerned. They only differ by the XML element they handle. Should think of a way to collapse them into a single template...
	The current node should be a 'Release' XML element.
	-->
	<xsl:template name="_printComposition">
		<xsl:variable name="release_current" select="position()"/>
		<xsl:variable name="release_newest">
			<xsl:choose>
				<xsl:when test="Composition">
					<xsl:value-of select="count(preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:when test="count(following-sibling::Release[count(Composition) > 0]) != 0">
					<xsl:value-of select="count((following-sibling::Release[count(Composition) > 0])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="release_oldest">
			<xsl:choose>
				<xsl:when test="count(../Release[position() >= $release_newest and Composition/@inherit = 'false']) != 0">
					<xsl:value-of select="count((../Release[position() >= $release_newest and Composition/@inherit = 'false'])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$release_newest &lt; count(../Release) or ../Release[last()]/Composition">
			<br/>
			<table class="composition" width="100%">
				<thead>
					<tr>
						<th>
							<i>
								<u>
									<font size="-1">Composition</font>
								</u>
							</i>
						</th>
					</tr>
				</thead>
				<tbody>
					<xsl:if test="Composition/Summary">
						<tr>
							<th colspan="3">
								<xsl:for-each select="Composition/Summary">
									<xsl:call-template name="_printContent"/>
								</xsl:for-each>
							</th>
						</tr>
					</xsl:if>
					<xsl:for-each select="../Release">
						<xsl:variable name="release" select="position()"/>
						<xsl:if test="position() >= $release_newest and position() &lt;= $release_oldest">
							<xsl:for-each select="Composition/Component">
								<xsl:if test="count(../../../Release[position() >= $release_newest and position() &lt; $release]/Composition/Component[@ID = current()/@ID]) = 0">
									<tr class="compositionComponent">
										<td>
											<xsl:choose>
												<xsl:when test="$release = $release_current">
													<xsl:text>[new] </xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>[from&#160;</xsl:text>
													<span class="version">
														<xsl:value-of select="../../@version"/>
													</span>
													<xsl:text>]</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:call-template name="_computeComponentHref">
												<xsl:with-param name="ID" select="@ID"/>
												<xsl:with-param name="version" select="@version"/>
											</xsl:call-template>
										</td>
										<td>
											<xsl:call-template name="_printContent"/>
										</td>
									</tr>
								</xsl:if>
							</xsl:for-each>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printRequirements">
		<xsl:variable name="release_current" select="position()"/>
		<xsl:variable name="release_newest">
			<xsl:choose>
				<xsl:when test="Requirements">
					<xsl:value-of select="count(preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:when test="count(following-sibling::Release[count(Requirements) > 0]) != 0">
					<xsl:value-of select="count((following-sibling::Release[count(Requirements) > 0])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="release_oldest">
			<xsl:choose>
				<xsl:when test="count(../Release[position() >= $release_newest and Requirements/@inherit = 'false']) != 0">
					<xsl:value-of select="count((../Release[position() >= $release_newest and Requirements/@inherit = 'false'])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$release_newest &lt; count(../Release) or ../Release[last()]/Requirements">
			<br/>
			<table class="requirement" width="100%">
				<thead>
					<tr>
						<th>
							<i>
								<u>
									<font size="-1">Requirements</font>
								</u>
							</i>
						</th>
					</tr>
				</thead>
				<tbody>
					<xsl:if test="Requirements/Summary">
						<tr>
							<th colspan="3">
								<xsl:for-each select="Requirements/Summary">
									<xsl:call-template name="_printContent"/>
								</xsl:for-each>
							</th>
						</tr>
					</xsl:if>
					<xsl:for-each select="../Release">
						<xsl:variable name="release" select="position()"/>
						<xsl:if test="position() >= $release_newest and position() &lt;= $release_oldest">
							<xsl:for-each select="Requirements/Component">
								<xsl:if test="count(../../../Release[position() >= $release_newest and position() &lt; $release]/Requirements/Component[@ID = current()/@ID]) = 0">
									<tr class="requirementComponent">
										<td>
											<xsl:choose>
												<xsl:when test="$release = $release_current">
													<xsl:text>[new] </xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>[from&#160;</xsl:text>
													<span class="version">
														<xsl:value-of select="../../@version"/>
													</span>
													<xsl:text>]</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:call-template name="_computeComponentHref">
												<xsl:with-param name="ID" select="@ID"/>
												<xsl:with-param name="version" select="@version"/>
											</xsl:call-template>
										</td>
										<td>
											<xsl:call-template name="_printContent"/>
										</td>
									</tr>
								</xsl:if>
							</xsl:for-each>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<xsl:template name="_printDependencies">
		<xsl:variable name="release_current" select="position()"/>
		<xsl:variable name="release_newest">
			<xsl:choose>
				<xsl:when test="Dependencies">
					<xsl:value-of select="count(preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:when test="count(following-sibling::Release[count(Dependencies) > 0]) != 0">
					<xsl:value-of select="count((following-sibling::Release[count(Dependencies) > 0])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="release_oldest">
			<xsl:choose>
				<xsl:when test="count(../Release[position() >= $release_newest and Requirements/@inherit = 'false']) != 0">
					<xsl:value-of select="count((../Release[position() >= $release_newest and Dependencies/@inherit = 'false'])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$release_newest &lt; count(../Release) or ../Release[last()]/Dependencies">
			<br/>
			<table class="dependency" width="100%">
				<thead>
					<tr>
						<th>
							<i>
								<u>
									<font size="-1">Dependencies</font>
								</u>
							</i>
						</th>
					</tr>
				</thead>
				<tbody>
					<xsl:if test="Dependencies/Summary">
						<tr>
							<th colspan="3">
								<xsl:for-each select="Dependencies/Summary">
									<xsl:call-template name="_printContent"/>
								</xsl:for-each>
							</th>
						</tr>
					</xsl:if>
					<xsl:for-each select="../Release">
						<xsl:variable name="release" select="position()"/>
						<xsl:if test="position() >= $release_newest and position() &lt;= $release_oldest">
							<xsl:for-each select="Dependencies/Component">
								<xsl:if test="count(../../../Release[position() >= $release_newest and position() &lt; $release]/Dependencies/Component[@ID = current()/@ID]) = 0">
									<tr class="dependencyComponent">
										<td>
											<xsl:choose>
												<xsl:when test="$release = $release_current">
													<xsl:text>[new] </xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>[from&#160;</xsl:text>
													<span class="version">
														<xsl:value-of select="../../@version"/>
													</span>
													<xsl:text>]</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:call-template name="_computeComponentHref">
												<xsl:with-param name="ID" select="@ID"/>
												<xsl:with-param name="version" select="@version"/>
											</xsl:call-template>
										</td>
										<td>
											<xsl:call-template name="_printContent"/>
										</td>
									</tr>
								</xsl:if>
							</xsl:for-each>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<xsl:template match="xrn:ReleaseNotes/Releases/Release/Features">
		<xsl:if test="Feature">
			<table class="feature" width="100%">
				<tbody>
					<xsl:for-each select="Feature[@ID]">
						<xsl:sort select="@ID"/>
						<xsl:if test="count(preceding-sibling::Feature[@ID = current()/@ID]) = 0">
							<tr class="featureHeader">
								<xsl:if test="@ID">
									<a>
										<xsl:attribute name="name"><xsl:value-of select="../../@version"/>_<xsl:value-of select="@ID"/></xsl:attribute>
									</a>
								</xsl:if>
								<td>
									<xsl:call-template name="_printFeatureIDInheritance"/>
								</td>
							</tr>
							<xsl:for-each select="../Feature[@ID = current()/@ID]">
								<xsl:call-template name="_printIndividualFeatureContent"/>
							</xsl:for-each>
						</xsl:if>
					</xsl:for-each>
					<xsl:for-each select="Feature[not(@ID)]">
						<tr class="featureHeader">
							<td>
								<xsl:text> </xsl:text>
							</td>
						</tr>
						<xsl:call-template name="_printIndividualFeatureContent"/>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<!--
	Prints the content of a single 'Feature' element, whitout its ID and inheritance description.
	The current node must be the 'Feature' XML element.
	The 'additionalHTMLStuff' parameter enables to add some HTML code after the 'Abstract'.
	Note that the template assumes that you are currently writting to a 'table/tbody' HTML tag. 
	-->
	<xsl:template name="_printIndividualFeatureContent">
		<xsl:param name="additionalHTMLStuff"/>
		<tr>
			<xsl:attribute name="class"><xsl:choose><xsl:when test="(position() mod 2) = 0">featureEven</xsl:when><xsl:otherwise>featureOdd</xsl:otherwise></xsl:choose></xsl:attribute>
			<td>
				<span>
					<xsl:attribute name="class"><xsl:text>featureImportance</xsl:text><xsl:choose><xsl:when test="@importance"><xsl:value-of select="@importance"/></xsl:when><xsl:otherwise>3</xsl:otherwise></xsl:choose></xsl:attribute>
					<xsl:if test="Abstract">
						<span class="featureSummary">
							<xsl:apply-templates select="Abstract"/>
						</span>
					</xsl:if>
					<xsl:copy-of select="$additionalHTMLStuff"/>
					<xsl:for-each select="Item">
						<div class="item">
							<xsl:call-template name="_printContent"/>
						</div>
					</xsl:for-each>
					<xsl:call-template name="_printTypeWhyFix"/>
					<xsl:call-template name="_printAskingPersons"/>
					<xsl:call-template name="_printContributors"/>
				</span>
			</td>
		</tr>
	</xsl:template>
	<!--
	The current node must be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printAskingPersons">
		<xsl:if test="count(@askingPersonID | AskingPersons/AskingPerson/@ID) > 0">
			<div align="right">
				<i>
					<font size="-1">
						<xsl:text>asking: </xsl:text>
					</font>
				</i>
				<span class="askingID">
					<xsl:choose>
						<xsl:when test="@askingPersonID">
							<xsl:value-of select="@askingPersonID"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:for-each select="AskingPersons/AskingPerson">
								<xsl:value-of select="@ID"/>
								<xsl:if test="position() != last()">
									<xsl:text>, </xsl:text>
								</xsl:if>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</span>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	The current node must be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printContributors">
		<xsl:if test="count(@contributorID | Contributors/Contributor/@ID) > 0">
			<div align="right">
				<i>
					<font size="-1">
						<xsl:text>contributor: </xsl:text>
					</font>
				</i>
				<span class="contributorID">
					<xsl:choose>
						<xsl:when test="@contributorID ">
							<xsl:value-of select="@contributorID "/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:for-each select="Contributors/Contributor">
								<xsl:value-of select="@ID"/>
								<xsl:if test="position() != last()">
									<xsl:text>, </xsl:text>
								</xsl:if>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</span>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	The current node must be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printTypeWhyFix">
		<div align="right">
			<i>
				<font size="-1">
					<xsl:text>detail: </xsl:text>
				</font>
			</i>
			<!--xsl:choose>
				<xsl:when test="$useIcons">
					<img>
						<xsl:attribute name="src"><xsl:value-of select="@type"/><xsl:text>.png</xsl:text></xsl:attribute>
						<xsl:attribute name="alt"><xsl:value-of select="@type"/></xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="@type"/></xsl:attribute>
					</img>
				</xsl:when>
				<xsl:otherwise-->
			<span>
				<xsl:attribute name="class"><xsl:value-of select="@type"/>Type</xsl:attribute>
				<xsl:value-of select="@type"/>
				<xsl:text> </xsl:text>
			</span>
			<!--/xsl:otherwise>
			</xsl:choose-->
			<xsl:if test="@fixID">
				<!--xsl:choose>
					<xsl:when test="$useIcons">
						<img src="bug.png" alt="bug-fixing" title="bug-fixing"/>
					</xsl:when>
					<xsl:otherwise-->
				<span class="bug">
					<xsl:text>bug-fixing </xsl:text>
				</span>
				<!--/xsl:otherwise>
				</xsl:choose-->
			</xsl:if>
			<xsl:if test="@why">
				<span class="why">
					<xsl:value-of select="@why"/>
					<xsl:text> </xsl:text>
				</span>
			</xsl:if>
			<xsl:if test="@category">
				<span class="category">
					<xsl:value-of select="@category"/>
					<xsl:text> </xsl:text>
				</span>
			</xsl:if>
		</div>
	</xsl:template>
	<!--
	This templates outputs the ID of a feature.
	The current node should be a 'Features/Feature' XML.
	Warning: this template has been overriden in the multiple HTML page XLST, so do not forget to modify it accordingly if you change this one.
	-->
	<xsl:template name="_printFeatureID">
		<xsl:value-of select="@ID"/>
	</xsl:template>
	<!--
	This templates outputs the ID and the inheritance of an individual feature. The inheritance will limit to the currently selected feature.
	The current node should be a 'Features/Feature' last XML element for which the inheritance is asked for.
	-->
	<xsl:template name="_printFeatureIDInheritance">
		<xsl:if test="@ID">
			<span class="visualNoPrint">
				<span class="featureID">
					<xsl:text>&lt;</xsl:text>
					<xsl:call-template name="_printFeatureID"/>
					<xsl:text>&gt;</xsl:text>
					<xsl:variable name="release_position" select="count(../../preceding-sibling::Release) + 1"/>
					<xsl:variable name="feature_id" select="@ID"/>
					<xsl:if test="../../../Release[position() &gt; $release_position]/Features/Feature[@ID = $feature_id]">
						<xsl:text>&#160;&#160;</xsl:text>
						<font class="version" size="-2">
							<xsl:for-each select="../../../Release[position() &gt; $release_position]/Features/Feature[@ID = $feature_id]">
								<xsl:if test="count(preceding-sibling::Feature[@ID = $feature_id]) = 0">
									<a>
										<xsl:attribute name="href"><xsl:call-template name="_computePointedFeatureHref"/></xsl:attribute>
										<xsl:text>[</xsl:text>
										<xsl:value-of select="../../@version"/>
										<xsl:text>]</xsl:text>
									</a>
									<xsl:if test="position() != last()">
										<xsl:text>, </xsl:text>
									</xsl:if>
								</xsl:if>
							</xsl:for-each>
						</font>
					</xsl:if>
					<br/>
				</span>
			</span>
		</xsl:if>
	</xsl:template>
	<!--
	This templates outputs the version header part of a release.
	The current node should be a 'Release/Release' XML element.
	-->
	<xsl:template name="_printReleaseVersion">
		<div class="versionTitle">
			<span class="version">
				<xsl:value-of select="@version"/>
			</span>
		</div>
		<xsl:if test="@buildDate != ''">
			<div align="right">
				<i>
					<font size="-1">build date: </font>
				</i>
				<span class="date">
					<xsl:value-of select="@buildDate"/>
				</span>
			</div>
		</xsl:if>
		<xsl:if test="@deliveryDate != ''">
			<div align="right">
				<i>
					<font size="-1">delivery date: </font>
				</i>
				<span class="date">
					<xsl:value-of select="@deliveryDate"/>
				</span>
			</div>
		</xsl:if>
		<xsl:if test="@builderID != ''">
			<div align="right">
				<i>
					<font size="-1">builder: </font>
				</i>
				<span class="askingID">
					<xsl:value-of select="@builderID"/>
				</span>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	This templates outputs the content informative part of a release.
	The current node should be a 'Release/Release' XML element.
	-->
	<xsl:template name="_printReleaseContent">
		<div class="releaseSummary">
			<xsl:for-each select="Summary">
				<xsl:call-template name="_printContent"/>
			</xsl:for-each>
		</div>
		<br/>
		<xsl:apply-templates select="Features"/>
		<xsl:if test="$composition = 'true'">
			<xsl:call-template name="_printComposition"/>
		</xsl:if>
		<xsl:if test="$dependency = 'true'">
			<xsl:call-template name="_printDependencies"/>
		</xsl:if>
		<xsl:if test="$requirement = 'true'">
			<xsl:call-template name="_printRequirements"/>
		</xsl:if>
	</xsl:template>
	<!--
	This templates outputs the delivery end-part of a release.
	The current node should be a 'Release/Release' XML element.
	-->
	<xsl:template name="_printReleaseDelivery">
		<br/>
		<xsl:choose>
			<xsl:when test="Deliveries">
				<table class="delivery" width="100%">
					<thead>
						<tr>
							<th>
								<i>
									<u>
										<font size="-1">Deliveries</font>
									</u>
								</i>
							</th>
						</tr>
					</thead>
					<tbody>
						<xsl:if test="Deliveries/Summary">
							<tr>
								<th colspan="2">
									<xsl:for-each select="Deliveries/Summary">
										<xsl:call-template name="_printContent"/>
									</xsl:for-each>
								</th>
							</tr>
						</xsl:if>
						<xsl:for-each select="Deliveries/Delivery">
							<tr>
								<td>
									<a>
										<xsl:attribute name="href"><xsl:if test="../../../../Deliveries/@href"><xsl:value-of select="../../../../Deliveries/@href"/><xsl:text>/</xsl:text></xsl:if><xsl:value-of select="@href"/></xsl:attribute>
										<xsl:value-of select="@href"/>
									</a>
								</td>
								<td>
									<xsl:call-template name="_printContent"/>
								</td>
							</tr>
						</xsl:for-each>
					</tbody>
				</table>
			</xsl:when>
			<xsl:otherwise>
				<table class="delivery" width="100%">
					<thead>
						<tr>
							<th>
								<i>
									<font size="-1">No delivery</font>
								</i>
							</th>
						</tr>
					</thead>
				</table>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Called when some content should be output.
	The current node must be of type 'xrn:contentType'.
	This template has been overriden in the multiple HTML page XLST, so do not forget to modify it accordingly if you chanage this one.
	-->
	<xsl:template name="_printContent">
		<xsl:choose>
			<xsl:when test="@contentType = 'html'">
				<xsl:copy-of select="."/>
			</xsl:when>
			<xsl:when test="@contentType = 'process'">
				<!--Not possible for the moment, we'll see how to do that for better framework integration...-->
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:when test="not(text())"/>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Prints the bottom banner of the framework.
	The 'copyrightXRNInternal' class CSS selector must be on when calling this template, because setting the selector here generates bad layout...
	-->
	<xsl:template name="_printBottomBanner">
		<xsl:if test="$banner">
			<div align="right">
				<xsl:text>Release notes generated by </xsl:text>
				<strong>
					<i>
						<a href="http://xmlreleasenotes.free.fr" target="_blank">XMLReleaseNotes</a>
					</i>
				</strong>
				<xsl:text> V</xsl:text>
				<xsl:value-of select="$_version"/>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	Prints the URL of the same feature, but at a different version stage, so that it can be referenced via an HTML anchor.
	The current node must be the 'Feature' XML element on which the reference is being computed.
	Warning: this template has been overriden in the multiple HTML page XLST, so do not forget to modify it accordingly if you change this one.
	-->
	<xsl:template name="_computePointedFeatureHref">
		<xsl:text>#</xsl:text>
		<xsl:value-of select="../../@version"/>
		<xsl:text>_</xsl:text>
		<xsl:value-of select="@ID"/>
	</xsl:template>
	<!--
	Prints the URL of the provided component HTML release notes, corresponding to the provided (optional) version.
	The top '/ReleaseNotes/Components' XML element should be accessible.
	-->
	<xsl:template name="_computeComponentHref">
		<xsl:param name="ID"/>
		<xsl:param name="version"/>
		<xsl:variable name="aText">
			<xsl:value-of select="$ID"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="$version"/>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="/*/Components/Component[@ID = $ID]">
				<a>
					<xsl:attribute name="href"><xsl:value-of select="/*/Components/Component[@ID = $ID]/@href"/></xsl:attribute>
					<xsl:value-of select="$aText"/>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$aText"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
